@@ -1,6 +1,7 @@
 package SeeAlso::Identifier;
 
-use Carp;
+use strict;
+use warnings;
 
 =head1 NAME
 
@@ -8,8 +9,8 @@ SeeAlso::Identifier - an identifier passed to a SeeAlso-Server
 
 =cut
 
-use vars qw($VERSION);
-$VERSION = "0.40";
+use Carp;
+our $VERSION = "0.41";
 
 =head1 DESCRIPTION
 
@@ -192,7 +193,7 @@ sub indexed {
     if (defined $self->{mIndexed}) {
         return &{$self->{mIndexed}}($self->{value});
     } else {
-        return $self->normalized;
+        return $self->normalized();
     }
 }
 
@@ -213,4 +214,16 @@ sub valid {
     }
 }
 
-1;
\ No newline at end of file
+1;
+
+=head1 AUTHOR
+
+Jakob Voss C<< <jakob.voss@gbv.de> >>
+
+=head1 LICENSE
+
+Copyright (C) 2007-2009 by Verbundzentrale Goettingen (VZG) and Jakob Voss
+
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself, either Perl version 5.8.8 or, at
+your option, any later version of Perl 5 you may have available.
