@@ -1,14 +1,18 @@
 package SeeAlso::Response;
 
-use JSON::XS qw(encode_json);
-
-use vars qw( $VERSION );
-$VERSION = "0.53";
+use strict;
+use warnings;
 
 =head1 NAME
 
 SeeAlso::Response - SeeAlso Simple Response
 
+=cut
+
+use JSON::XS qw(encode_json);
+
+our $VERSION = "0.53";
+
 =head1 DESCRIPTION
 
 This class models a SeeAlso Simple Response which is practically the
@@ -59,6 +63,11 @@ sub new {
 =head2 add ( $label [, $description [, $uri ] ] )
 
 Add an item to the result set. All parameters must be strings.
+The URI is not checked for well-formedness, so it is recommended
+to use a specific URI class like C<URI> and pass a normalized
+version of the URI:
+
+  $uri = URI->new( $uri_str )->canonical
 
 =cut
 
@@ -125,3 +134,15 @@ sub toJSON {
 }
 
 1;
+
+=head1 AUTHOR
+
+Jakob Voss C<< <jakob.voss@gbv.de> >>
+
+=head1 LICENSE
+
+Copyright (C) 2007-2009 by Verbundzentrale Goettingen (VZG) and Jakob Voss
+
+This library is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself, either Perl version 5.8.8 or, at
+your option, any later version of Perl 5 you may have available.
